.. _quickstart:

Quickstart
==========

.. currentmodule:: flask_collect

Flask-Collect-Invenio is easy to use.  For the complete guide, checkout out the
API documentation on the :class:`Collect` class.

You can run: ::

    collect.collect(verbose=True)

or with command:

    $ ./manage.py collect
